@@ -9,22 +9,24 @@ from configflow.sources import abstract
 class CommandLineArgumentError(Exception):
     """Raises if the user passed an invalid command-line argument."""
 
-    def __init__(self, command_line_argument: str) -> None:
+    def __init__(self, msg: str, command_line_argument: str) -> None:
         """Initialize.
 
         Examples
         --------
-        >>> raise CommandLineArgumentError(command_line_argument="-c")
+        >>> raise CommandLineArgumentError(
+        ...     msg="Argument {0!r} doesn't have value.",
+        ...     command_line_argument="-c"
+        ... )
         Traceback (most recent call last):
         ...
         configflow.exceptions.sources.CommandLineArgumentError: ...
         """
 
-        msg = misc.string.ErrorMessage("Argument {0!r} doesn't have value.")
-        super().__init__(msg.format(command_line_argument))
+        super().__init__(misc.string.ErrorMessage(msg).format(command_line_argument))
 
 
-class InvalidSourceError(Exception):
+class SourceError(Exception):
     """Raises if the user passed an invalid source of a configuration."""
 
     def __init__(self, source: abstract.Source, msg: str) -> None:
@@ -32,10 +34,10 @@ class InvalidSourceError(Exception):
 
         Examples
         --------
-        >>> raise InvalidSourceError(abstract.Source(), "Filepath is not set.")
+        >>> raise SourceError(abstract.Source(), "Filepath is not set.")
         Traceback (most recent call last):
         ...
-        configflow.exceptions.sources.InvalidSourceError: ...
+        configflow.exceptions.sources.SourceError: ...
         """
 
         super().__init__(misc.string.ErrorMessage("{0!s}. Source:\n{1!r}").format(msg, source))
