@@ -2,16 +2,14 @@
 
 from __future__ import annotations
 
+import typing
 import warnings
 
-from typing import Any
-from typing import Callable
 
-import decorator
+FunctionType = typing.Callable[[typing.Any], typing.Any]
 
 
-@decorator.decorator
-def deprecated(function: Callable[[Any], Any], *args, **kwargs) -> Any:
+def deprecated(function: FunctionType) -> typing.Any:
     """Show warning about the depreciation of a function or method.
 
     Examples
@@ -26,5 +24,10 @@ def deprecated(function: Callable[[Any], Any], *args, **kwargs) -> Any:
     [<warnings.WarningMessage object at ...]
     """
 
-    warnings.warn("Function {0!r} is deprecated.".format(function.__name__), DeprecationWarning)
-    return function(*args, **kwargs)
+    def wrapper(*args, **kwargs) -> typing.Any:
+        """Show warning about the depreciation of a function or method."""
+
+        warnings.warn("Function {0!r} is deprecated.".format(function.__name__), DeprecationWarning)
+        return function(*args, **kwargs)
+
+    return wrapper
